@@ -1,18 +1,13 @@
-import xnat
-from mlops.utils.logger import logger
-from itertools import chain
-import mlflow
-import pandas as pd
-
-import xnat
-from mlops.utils.logger import logger
-from itertools import chain
-import mlflow
-import pandas as pd
-import requests
 import asyncio
-from timeit import default_timer
+import logging
 from concurrent.futures import ThreadPoolExecutor
+from itertools import chain
+import tqdm
+import mlflow
+import pandas as pd
+import xnat
+
+logger = logging.getLogger(__name__)
 
 
 class DataBuilderXNAT:
@@ -39,6 +34,7 @@ class DataBuilderXNAT:
                               user=self.xnat_configuration['user'],
                               password=self.xnat_configuration['password'],
                               verify=self.xnat_configuration['verify'],
+                              loglevel='ERROR',
                               ) as session:
 
                 logger.info(f"Collecting XNAT project: {self.xnat_configuration['project']}")
@@ -59,6 +55,9 @@ class DataBuilderXNAT:
                     )
                     for subject_i in project_subjects
                 ]
+
+                responses = [await f for f in tqdm.tqdm(asyncio.as_completed(tasks), total=len(tasks))]
+
                 for response in await asyncio.gather(*tasks):
                     pass
 
@@ -72,8 +71,7 @@ class DataBuilderXNAT:
                        'subject_id': project.subjects[subject.id].label,
                        'data': []}
 
-        logger.info(f'checking subject {subject_i}')
-
+        logger.debug(f'checking subject {subject_i}')
         if self.actions:
             try:
                 data = []
@@ -87,7 +85,7 @@ class DataBuilderXNAT:
                         self.missing_data_log.append({'subject_id': subject_i.id,
                                                       'action_data': subject_i.label,
                                                       'failed_action': action})
-                        logger.warn(f'No data found for {subject_i}: action {action} removing sample')
+                        logger.debug(f'No data found for {subject_i}: action {action} removing sample')
                         raise Exception
 
                     elif type(xnat_obj) == list:
@@ -106,7 +104,7 @@ class DataBuilderXNAT:
                     data.append(action_data)
 
             except Exception as e:
-                logger.warn(f'No data found for {subject_i}; removing sample. Exception {e}')
+                logger.debug(f'No data found for {subject_i}; removing sample. Exception {e}')
                 pass
 
             if self.flatten_output:
@@ -131,6 +129,7 @@ def xnat_build_dataset(xnat_configuration: dict, actions: list = None, flatten_o
                       user=xnat_configuration['user'],
                       password=xnat_configuration['password'],
                       verify=xnat_configuration['verify'],
+                      loglevel='ERROR',
                       ) as session:
 
         logger.info(f"Collecting XNAT project: {xnat_configuration['project']}")
@@ -165,7 +164,7 @@ def xnat_build_dataset(xnat_configuration: dict, actions: list = None, flatten_o
                                 missing_data_log.append({'subject_id': subject_i.id,
                                                          'action_data': subject_i.label,
                                                          'failed_action': action})
-                                logger.warn(f'No data found for {subject_i}: action {action} removing sample')
+                                logger.debug(f'No data found for {subject_i}: action {action} removing sample')
                                 raise Exception
 
                             for obj in xnat_obj:
@@ -183,7 +182,7 @@ def xnat_build_dataset(xnat_configuration: dict, actions: list = None, flatten_o
                         data.append(action_data)
 
                 except Exception as e:
-                    logger.warn(f'No data found for {subject_i}; removing sample. Exception {e}')
+                    logger.debug(f'No data found for {subject_i}; removing sample. Exception {e}')
                     continue
 
                 if flatten_output:
