@@ -2,9 +2,11 @@ import configparser
 import os
 
 import docker
+import logging
 
 from mlops.Experiment import Experiment
 
+logger = logging.getLogger(__name__)
 
 class TestExperiment:
 
@@ -48,7 +50,10 @@ class TestExperiment:
 
     def test_print_experiment_info(self, caplog):
         # Check correct information is printed to console
-        self.experiment.print_experiment_info()  # Call function.
+        with caplog.at_level(logging.INFO):
+            # self.experiment = Experiment('test_entry.py', config_path='tests/data/test_config.cfg',
+            #                              project_path='tests/data')
+            self.experiment.print_experiment_info()  # Call function.
         assert 'Name: test_project' in caplog.text
 
     def test_build_project_file(self):
